Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2021-03-12 21:09:23 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2021-03-12 21:09:23 +0300
commitee4105895ebffdc6185d20f4592031723a76fedc (patch)
tree2c723287e54f4131ccb95ad0e8b1e0609311621b /scripts
parent006000e366ad5dc61966770d33e3afd4c07e728d (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/lint-doc.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/lint-doc.sh b/scripts/lint-doc.sh
index c94faa8f6f4..4d0c1ba99d2 100755
--- a/scripts/lint-doc.sh
+++ b/scripts/lint-doc.sh
@@ -30,13 +30,13 @@ then
((ERRORCODE++))
fi
# Test for non-standard spaces (NBSP, NNBSP) in documentation.
echo '=> Checking for non-standard spaces...'
echo
-grep --extended-regexp --binary-file=without-match --recursive '[  ]' doc/ >/dev/null 2>&1
+grep --extended-regexp --binary-file=without-match --recursive '[  ​]' doc/ >/dev/null 2>&1
if [ $? -eq 0 ]
then
- echo '✖ ERROR: Non-standard spaces (NBSP, NNBSP) should not be used in documentation.
+ echo '✖ ERROR: Non-standard spaces (NBSP, NNBSP, ZWSP) should not be used in documentation.
https://docs.gitlab.com/ee/development/documentation/styleguide/index.html#spaces-between-words
Replace with standard spaces:' >&2
# Find the spaces, then add color codes with sed to highlight each NBSP or NNBSP in the output.
@@ -30,13 +30,13 @@ then
((ERRORCODE++))
fi
-# Test for non-standard spaces (NBSP, NNBSP) in documentation.
+# Test for non-standard spaces (NBSP, NNBSP, ZWSP) in documentation.
echo '=> Checking for non-standard spaces...'
echo